==> v1.4.0.zip: ombi/PlexRequests.UI/Validators/EmailNotificationSettingsValidator.cs <==
﻿#region Copyright
// /************************************************************************
//    Copyright (c) 2016 Jamie Rees
//    File: SonarrValidator.cs
//    Created By: Jamie Rees
//   
//    Permission is hereby granted, free of charge, to any person obtaining
//    a copy of this software and associated documentation files (the
//    "Software"), to deal in the Software without restriction, including
//    without limitation the rights to use, copy, modify, merge, publish,
//    distribute, sublicense, and/or sell copies of the Software, and to
//    permit persons to whom the Software is furnished to do so, subject to
//    the following conditions:
//   
//    The above copyright notice and this permission notice shall be
//    included in all copies or substantial portions of the Software.
//   
//    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
//    EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
//    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
//    NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
//    LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
//    OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
//    WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//  ************************************************************************/
#endregion
using FluentValidation;

using PlexRequests.Core.SettingModels;

namespace PlexRequests.UI.Validators
{
    public class EmailNotificationSettingsValidator : AbstractValidator<EmailNotificationSettings>
    {
        public EmailNotificationSettingsValidator()
        {
            RuleFor(request => request.EmailHost).NotEmpty().WithMessage("You must specify a Host name.");
            RuleFor(request => request.EmailPort).NotEmpty().WithMessage("You must specify a Port.");
            RuleFor(request => request.RecipientEmail).NotEmpty().WithMessage("You must specify a Recipient.");
            RuleFor(request => request.RecipientEmail).EmailAddress().WithMessage("You must specify a valid Recipient.");
            RuleFor(request => request.EmailUsername).EmailAddress().WithMessage("You must specify a valid Username.");
            RuleFor(request => request.EmailUsername).NotEmpty().WithMessage("You must specify a Username.");
            RuleFor(request => request.EmailPassword).NotEmpty().WithMessage("You must specify a valid password.");
        }
    }
}

==> v1.5.0.zip: ombi/PlexRequests.UI/Validators/EmailNotificationSettingsValidator.cs <==
﻿#region Copyright
// /************************************************************************
//    Copyright (c) 2016 Jamie Rees
//    File: SonarrValidator.cs
//    Created By: Jamie Rees
//   
//    Permission is hereby granted, free of charge, to any person obtaining
//    a copy of this software and associated documentation files (the
//    "Software"), to deal in the Software without restriction, including
//    without limitation the rights to use, copy, modify, merge, publish,
//    distribute, sublicense, and/or sell copies of the Software, and to
//    permit persons to whom the Software is furnished to do so, subject to
//    the following conditions:
//   
//    The above copyright notice and this permission notice shall be
//    included in all copies or substantial portions of the Software.
//   
//    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
//    EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
//    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
//    NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
//    LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
//    OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
//    WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//  ************************************************************************/
#endregion
using FluentValidation;

using PlexRequests.Core.SettingModels;

namespace PlexRequests.UI.Validators
{
    public class EmailNotificationSettingsValidator : AbstractValidator<EmailNotificationSettings>
    {
        public EmailNotificationSettingsValidator()
        {
            RuleFor(request => request.EmailHost).NotEmpty().WithMessage("You must specify a Host name.");
            RuleFor(request => request.EmailPort).NotEmpty().WithMessage("You must specify a Port.");
            RuleFor(request => request.RecipientEmail).NotEmpty().WithMessage("You must specify a Recipient.");
            RuleFor(request => request.RecipientEmail).EmailAddress().WithMessage("You must specify a valid Recipient.");
            RuleFor(request => request.EmailUsername).NotEmpty().WithMessage("You must specify a Username.");
            RuleFor(request => request.EmailPassword).NotEmpty().WithMessage("You must specify a valid password.");
            RuleFor(request => request.EmailSender).EmailAddress().WithMessage("You must specify a valid Email for the email sender.");
            RuleFor(request => request.EmailSender).NotEmpty().WithMessage("You must specify a Email Sender.");
        }
    }
}
